@@ -12,21 +12,24 @@ from pydantic import BaseModel
 class ServerCredentials(BaseModel):
     """Container for credentials for bot."""
 
+    #: bot that retrieved token from API.
     bot_id: UUID
-    """bot that retrieved token from API."""
+
+    #: token generated for bot.
     token: str
-    """token generated for bot."""
 
 
 class ExpressServer(BaseModel):
     """Server on which bot can answer."""
 
+    #: host name of server.
     host: str
-    """host name of server."""
+
+    #: secret that will be used for generating signature for bot.
     secret_key: str
-    """secret that will be used for generating signature for bot."""
+
+    #: obtained credentials for bot.
     server_credentials: Optional[ServerCredentials] = None
-    """obtained credentials for bot."""
 
     def calculate_signature(self, bot_id: UUID) -> str:
         """Calculate signature for obtaining token for bot from BotX API.
@@ -42,5 +45,5 @@ class ExpressServer(BaseModel):
                 key=self.secret_key.encode(),
                 msg=str(bot_id).encode(),
                 digestmod=hashlib.sha256,
-            ).digest()
+            ).digest(),
         ).decode()
